@@ -1,5 +1,5 @@
-#ifndef __XML6_ENTITIES_H
-#define __XML6_ENTITIES_H
+#ifndef __XML6_ENTITY_H
+#define __XML6_ENTITY_H
 
 #include <libxml/entities.h>
 
@@ -8,4 +8,4 @@ xml6_entity_create(const xmlChar *name, int type,
                    const xmlChar *ExternalID, const xmlChar *SystemID,
                    const xmlChar *content);
 
-#endif /* __XML6_ENTITIES_H */
+#endif /* __XML6_ENTITY_H */
